var jPhidget22 = require('phidget22');

var SERVER_PORT = 5661;

function main() {

	if (process.argv.length != 3) {
		console.log('usage: node VoltageRatioInput.js <server address>');
		process.exit(1);
	}

	var url = 'phid://' + process.argv[2] + ':' + SERVER_PORT;

	console.log('connecting to:' + url);
	var conn = new jPhidget22.Connection(url, { name: 'Server Connection', passwd: '' });
	conn.connect()
	  .then(runExample)
	  .catch(function (err) {
	  	console.log('Error running example:' + err);
		process.exit(1);
	  });
}

function runExample() {

	var ch = new jPhidget22.VoltageRatioInput();

	ch.onAttach = function (ch) {
		console.log(ch + ' attached');
		if(ch.getDeviceID() == jPhidget22.DeviceID.PHIDID_1046) {
			ch.setBridgeGain(jPhidget22.BridgeGain.BRIDGE_GAIN_128);
			ch.setBridgeEnabled(true);
		}
	};

	ch.onDetach = function (ch) {
		console.log(ch + ' detached');
	};

	/* Uncomment the following lines to connect to a hub port */
	//ch.setHubPort(0);
	//ch.setIsHubPort(true);	/* open the VINT hub port */

	ch.onVoltageRatioChange = function (ratio) {
		console.log('voltage ratio change:' + ratio + ' (' + this.getVoltageRatio() + ')');
	};

	/* unit[unit|name|symbol] */
	ch.onSensorChange = function (value, unit) {
		console.log('voltage ratio sensor change:' + value + unit.symbol);
	};

	ch.open().then(function (ch) {
		console.log('channel open');
		/*
		 * This is a good place to set the sensor type, or enable a bridge.
		 */
	}).catch(function (err) {
		console.log('failed to open the channel:' + err);
	});
}

if (require.main === module)
	main();
